@@ -34,20 +34,10 @@ class IOHandlerTiger(BaseIOHandler):
         BaseIOHandler.__init__(self, *args, **kwargs)
         self._memmaps = {}
 
-    def _read_data_set(self, grid, field):
+    def _read_data(self, grid, field):
         fn = grid.pf.basename + grid.hierarchy.file_mapping[field]
-        LD = na.array(grid.left_dims, dtype='int64')
-        SS = na.array(grid.ActiveDimensions, dtype='int64')
-        RS = na.array(grid.pf.root_size, dtype='int64')
-        data = au.read_tiger_section(fn, LD, SS, RS).astype("float64")
-        return data
-
-    def _read_data_slice(self, grid, field, axis, coord):
-        fn = grid.pf.basename + grid.hierarchy.file_mapping[field]
-        LD = na.array(grid.left_dims, dtype='int64').copy()
-        SS = na.array(grid.ActiveDimensions, dtype='int64').copy()
-        RS = na.array(grid.pf.root_size, dtype='int64').copy()
-        LD[axis] += coord
-        SS[axis] = 1
+        LD = np.array(grid.left_dims, dtype='int64')
+        SS = np.array(grid.ActiveDimensions, dtype='int64')
+        RS = np.array(grid.pf.root_size, dtype='int64')
         data = au.read_tiger_section(fn, LD, SS, RS).astype("float64")
         return data
